@@ -18,6 +18,8 @@ App::gh::Command::Drop - drop a repository.
 
 sub run {
     my ($self,$repo) = @_;
+    return App::gh::Command->invoke('help', 'drop')
+        unless defined $repo;
 
 	my $gh_id = App::gh->config->github_id();
 	my $gh_token = App::gh->config->github_token();
@@ -25,11 +27,9 @@ sub run {
     $repo =~ s{::}{-}g;
 
     unless( $gh_id && $gh_token ) {
-        die "Github authtoken not found. Can not fork repository.\n";
+        die "Github authtoken not found. Can not delete repository.\n";
     }
 
-    die unless $repo;
-
     print "Deleting @{[ $gh_id ]}/@{[ $repo ]}\n";
 
     # repos/delete/:user/:repo
